var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Connector } from '@web3-react/types';
export class Url extends Connector {
    /**
     * @param url - An RPC url.
     * @param connectEagerly - A flag indicating whether connection should be initiated when the class is constructed.
     */
    constructor(actions, url, connectEagerly = false) {
        super(actions);
        if (connectEagerly && typeof window === 'undefined') {
            throw new Error('connectEagerly = true is invalid for SSR, instead use the activate method in a useEffect');
        }
        this.url = url;
        if (connectEagerly)
            void this.activate();
    }
    isomorphicInitialize() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.eagerConnection)
                return this.eagerConnection;
            yield (this.eagerConnection = Promise.all([
                import('@ethersproject/providers').then(({ JsonRpcProvider }) => JsonRpcProvider),
                import('@ethersproject/experimental').then(({ Eip1193Bridge }) => Eip1193Bridge),
            ]).then(([JsonRpcProvider, Eip1193Bridge]) => {
                const provider = new JsonRpcProvider(this.url);
                this.provider = new Eip1193Bridge(provider.getSigner(), provider);
            }));
        });
    }
    /** {@inheritdoc Connector.activate} */
    activate() {
        return __awaiter(this, void 0, void 0, function* () {
            this.actions.startActivation();
            yield this.isomorphicInitialize();
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            return this.provider.request({ method: 'eth_chainId' })
                .then((chainId) => {
                this.actions.update({ chainId, accounts: [] });
            })
                .catch((error) => {
                this.actions.reportError(error);
            });
        });
    }
}
